@@ -103,10 +103,10 @@ GainCurvePlot = function(frame, xvar, truthVar, title, ...) {
 
   # transform the frame into the tall form, for plotting
   results <-
-    cdata::unpivotValuesToRows(results,
-                               nameForNewKeyColumn = 'sort_criterion',
-                               nameForNewValueColumn = 'pct_outcome',
-                               columnsToTakeFrom = c('model', 'wizard'))
+    cdata::unpivot_to_blocks(results,
+                             nameForNewKeyColumn = 'sort_criterion',
+                             nameForNewValueColumn = 'pct_outcome',
+                             columnsToTakeFrom = c('model', 'wizard'))
   # rename sort_criterion
   sortKeyM <- c('model' = paste('model: sort by', xvar),
                'wizard' = paste('wizard: sort by', truthVar))
