@@ -22,6 +22,14 @@ NULL
 #' @importFrom wrapr :=
 NULL
 
+#' @importFrom utils packageVersion
+NULL
+
+#' @importFrom mgcv gam
+NULL
+
+#' @importFrom seplyr novelName
+NULL
 
 # re-export so old code and demos work (from when functions were here)
 
